@@ -1,7 +1,6 @@
 from bolinette.environment import env
 from bolinette.bcrypt import bcrypt
-import bolinette.models
-import bolinette.controllers
-import bolinette.topics
+import bolinette.defaults
+import bolinette.init
 from bolinette.commands import command
 from bolinette.bolinette import Bolinette
