@@ -3,33 +3,35 @@ import inspect
 
 from aiohttp import web as aio_web
 
-from bolinette import env, network, bcrypt, db, services, web, ws
+from bolinette import env, core
 from bolinette.commands import commands
 
 
 class Bolinette:
     def __init__(self, *, profile=None, overrides=None):
         env.init_app(profile=profile, overrides=overrides)
-        db.engine.init_app()
-        services.init_services()
-        network.jwt.init_app()
-        bcrypt.init_app()
-        web.resources.init_app()
-        ws.resources.init_app()
+
+        self.app = aio_web.Application()
+        self.context = core.BolinetteContext(self.app)
+        self.app['blnt'] = self.context
+
+        self.run_init_functions(self.app)
+
+    @staticmethod
+    def run_init_functions(app):
+        for func in core.cache.init_funcs:
+            func(app['blnt'])
 
     def run(self):
-        aio_web.run_app(web.resources.app)
-
-    @property
-    def app(self):
-        return web.resources.app
+        aio_web.run_app(self.app, port=self.context.env['port'])
 
     def run_command(self, name, **kwargs):
+        kwargs['blnt'] = self
         if name in commands.commands:
             func = commands.commands[name]
             if inspect.isfunction(func):
                 if inspect.iscoroutinefunction(func):
                     loop = asyncio.get_event_loop()
-                    loop.run_until_complete(func(**kwargs))
+                    loop.run_until_complete(func(self.context, **kwargs))
                 else:
                     func(**kwargs)
