@@ -1,22 +1,22 @@
 from typing import Type, Callable, List, Union, Tuple
 
-from bolinette import core, data, types
+from bolinette import core, blnt, types
 
 
 def model(model_name: str):
-    def decorator(model_cls: Type['data.Model']):
-        model_cls.__blnt__ = data.ModelMetadata(model_name)
+    def decorator(model_cls: Type['blnt.Model']):
+        model_cls.__blnt__ = blnt.ModelMetadata(model_name)
         core.cache.models[model_name] = model_cls
         return model_cls
     return decorator
 
 
 def model_property(function):
-    return data.ModelProperty(function.__name__, function)
+    return blnt.ModelProperty(function.__name__, function)
 
 
 def mixin(mixin_name: str):
-    def decorator(mixin_cls: Type['data.Mixin']):
+    def decorator(mixin_cls: Type['blnt.Mixin']):
         core.cache.mixins[mixin_name] = mixin_cls
         return mixin_cls
     return decorator
@@ -44,16 +44,16 @@ def seeder(func):
 
 
 def service(service_name: str, *, model_name: str = None):
-    def decorator(service_cls: Type[Union['data.Service', 'data.SimpleService']]):
-        service_cls.__blnt__ = data.ServiceMetadata(service_name, model_name or service_name)
+    def decorator(service_cls: Type[Union['blnt.Service', 'blnt.SimpleService']]):
+        service_cls.__blnt__ = blnt.ServiceMetadata(service_name, model_name or service_name)
         core.cache.services[service_name] = service_cls
         return service_cls
     return decorator
 
 
 def controller(controller_name: str, path: str, *, service_name: str = None):
-    def decorator(controller_cls: Type[Union['data.Controller', 'data.SimpleController']]):
-        controller_cls.__blnt__ = data.ControllerMetadata(controller_name, path, service_name or controller_name)
+    def decorator(controller_cls: Type[Union['blnt.Controller', 'blnt.SimpleController']]):
+        controller_cls.__blnt__ = blnt.ControllerMetadata(controller_name, path, service_name or controller_name)
         core.cache.controllers[controller_name] = controller_cls
         return controller_cls
     return decorator
@@ -64,19 +64,19 @@ def route(path: str, *, method: types.web.HttpMethod, access: 'types.web.AccessT
           roles: List[str] = None):
     if expects is not None:
         if isinstance(expects, tuple):
-            expects = data.ControllerExcepts(expects[0], expects[1] if len(expects) > 1 else 'default',
+            expects = blnt.ControllerExcepts(expects[0], expects[1] if len(expects) > 1 else 'default',
                                              patch='patch' in expects[2:])
         elif isinstance(expects, str):
-            expects = data.ControllerExcepts(expects)
+            expects = blnt.ControllerExcepts(expects)
     if returns is not None:
         if isinstance(returns, tuple):
-            returns = data.ControllerReturns(returns[0], returns[1] if len(returns) > 1 else 'default',
+            returns = blnt.ControllerReturns(returns[0], returns[1] if len(returns) > 1 else 'default',
                                              as_list='as_list' in returns[2:], skip_none='skip_none' in returns[2:])
         elif isinstance(returns, str):
-            returns = data.ControllerReturns(returns)
+            returns = blnt.ControllerReturns(returns)
 
     def decorator(route_function: Callable):
-        return data.ControllerRoute(route_function, path, method, access, expects, returns, roles)
+        return blnt.ControllerRoute(route_function, path, method, access, expects, returns, roles)
     return decorator
 
 
@@ -109,8 +109,8 @@ def delete(path: str, *, access=None, expects=None, returns=None, roles: List[st
 
 
 def topic(topic_name: str):
-    def decorator(topic_cls: Type['data.Topic']):
-        topic_cls.__blnt__ = data.TopicMetadata(topic_name)
+    def decorator(topic_cls: Type['blnt.Topic']):
+        topic_cls.__blnt__ = blnt.TopicMetadata(topic_name)
         core.cache.topics[topic_name] = topic_cls
         return topic_cls
     return decorator
@@ -118,5 +118,5 @@ def topic(topic_name: str):
 
 def channel(rule: str):
     def decorator(channel_function: Callable):
-        return data.TopicChannel(channel_function, rule)
+        return blnt.TopicChannel(channel_function, rule)
     return decorator
