@@ -1,11 +1,16 @@
 from aiohttp import web as aio_web
 
-from bolinette import data, types
+from bolinette import blnt, types
 from bolinette.decorators import controller, get
+from bolinette.defaults.services import FileService
 
 
 @controller('file', '/file')
-class FileController(data.Controller):
+class FileController(blnt.Controller):
+    @property
+    def file_service(self) -> FileService:
+        return self.context.service('file')
+
     def default_routes(self):
         return [
             self.defaults.get_one(key='key')
@@ -18,5 +23,5 @@ class FileController(data.Controller):
         headers = {
             'Content-disposition': f'attachment; filename={file.name}'
         }
-        return aio_web.Response(body=self.service.file_sender(file.key),
+        return aio_web.Response(body=self.file_service.file_sender(file.key),
                                 headers=headers, content_type=file.mime)
