@@ -1,9 +1,9 @@
-from bolinette import data
+from bolinette import blnt
 from bolinette.decorators import controller
 
 
 @controller('role', '/role')
-class RoleController(data.Controller):
+class RoleController(blnt.Controller):
     def default_routes(self):
         return [
             self.defaults.get_all(roles=['admin']),
